@@ -336,6 +336,7 @@ compile_sys = function(name, sys,
   code = gsub("__FUNCNAME__", name, code)
   if (compile)
   {
+    Sys.setenv(CXX_STD = "CXX11") # just in case
     res = try(Rcpp::sourceCpp(code = code, env = env, ...))
     if (!inherits(res, "try-error"))
     {
@@ -344,9 +345,12 @@ compile_sys = function(name, sys,
         do.call(paste0(name, "_set_observer"), list(f = observer), envir = env)
         do.call(paste0(name, "_set_output_processor"), list(f = proc_output), envir = env)
       }
-      if (name %in% search())
-        detach(pos = match(name, search()))
-      do.call("attach", list(what = env, name = name))
+      if (!identical(env, globalenv()))
+      {
+        if (name %in% search())
+          detach(pos = match(name, search()))
+        do.call("attach", list(what = env, name = name))
+      }
     }
   }
   return(invisible(code))
